﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Windows.Forms;
using HeuristicLab.Core;
using HeuristicLab.Core.Views;
using HeuristicLab.DataPreprocessing.Filter;
using HeuristicLab.MainForm;

namespace HeuristicLab.DataPreprocessing.Views {

  [View("Filter View")]
  [Content(typeof(FilterContent), false)]
  public partial class FilterView : ItemView {

    public new FilterContent Content {
      get { return (FilterContent)base.Content; }
      set { base.Content = value; }
    }

    public FilterView() {
      InitializeComponent();
      listView1.SmallImageList = new ImageList();
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
    }

    // Filter Contents
    private IDictionary<IFilter, ListViewItem> filters = new Dictionary<IFilter, ListViewItem>();

    private void listView1_DoubleClick(object sender, EventArgs e) {

    }

    private void newFilter_Click(object sender, EventArgs e) {
      //TODO Filter Choose View...
      IFilter filter = new ComparisonFilter();
      //filter.FilterName = "ComparisonFilter" + (i++);
      //filter.PropertyChanged += filter_PropertyChanged;

      ListViewItem filterViewItem = CreateListViewItem(filter);
      filters.Add(filter, filterViewItem);
      //add view items to content list view
      listView1.Items.Add(filterViewItem);
      //select top filter
      listView1.SelectedIndices.Add(0);
    }

    private void filter_PropertyChanged(object sender, PropertyChangedEventArgs e) {
      ListViewItem listViewItem;
      try {
        IFilter filter = (IFilter)sender;
        filters.TryGetValue(filter, out listViewItem);
        listViewItem.Name = filter.ItemName;
      } catch (KeyNotFoundException) {
        //nothing to do
      }

    }

    private ListViewItem CreateListViewItem(IFilter filter) {
      ListViewItem listViewItem = new ListViewItem();

      listViewItem.Text = filter.ItemName;
      listView1.SmallImageList.Images.Add(filter.ItemImage);
      listViewItem.ImageIndex = listView1.SmallImageList.Images.Count - 1;
      listViewItem.Tag = filter;
      return listViewItem;
    }

    private void deleteFilter_Click(object sender, EventArgs e) {
      //delete view item of filter
      //listView1.Items.Remove();
      //select top filter
      if (listView1.Items.Count > 0) {
        listView1.SelectedItems[0].Remove();
      }
      if (listView1.Items.Count > 0) {
        listView1.SelectedIndices.Add(0);
      }
    }

    private void listView1_SelectedIndexChanged(object sender, EventArgs e) {
      if (listView1.SelectedItems.Count > 0) {
        ListViewItem listViewItem = (ListViewItem)listView1.SelectedItems[0];
        this.viewHost.Content = (IItem)listViewItem.Tag;
      }
    }

    private void listView1_DoubleClick_1(object sender, EventArgs e) {
      if (listView1.SelectedItems.Count > 0) {
        ListViewItem listViewItem = (ListViewItem)listView1.SelectedItems[0];
        MainFormManager.MainForm.ShowContent((IItem)listViewItem.Tag);
      }
    }

  }
}
